Package 'auto.pca'

Title: Automatic Variable Reduction Using Principal Component Analysis
Description: PCA done by eigenvalue decomposition of a data correlation matrix, here it automatically determines the number of factors by eigenvalue greater than 1 and it gives the uncorrelated variables based on the rotated component scores, Such that in each principal component variable which has the high variance are selected. It will be useful for non-statisticians in selection of variables. For more information, see the <http://www.ijcem.org/papers032013/ijcem_032013_06.pdf> web page.
Authors: Navinkumar Nedunchezhian
Maintainer: Navinkumar Nedunchezhian <[email protected]>
License: GPL-2
Version: 0.3
Built: 2026-05-20 07:17:41 UTC
Source: https://github.com/cran/auto.pca

Help Index


Automatic Variable Reduction Using Principal Component Analysis

Description

Prints the uncorrelated variables from the input dataframe

Usage

auto.pca(input_data)

Arguments

input_data

dataframe without ID Variables & Categorical Variables

Examples

auto.pca(attitude)